function wordInsertQuestion(options) {

    options = processOptionsMap({
        question: {
            required: true,
            process: {
                jQueryObj: "#question"
            }
        },
        sentence: {
            required: true
        },
        survey_language: {
            required: false,
            default: 'en'
        },
        show_question_text: {
            required: false,
            default: false
        }
    }, options);

    var finalString = options.sentence,
        targets = [],
        documentLanguage = document.documentElement.lang;

    // adjust finalString for additional langauges
    if (options.survey_language !== "en") {
        var languageIndex = options.survey_language.split("@").indexOf(documentLanguage);
        finalString = finalString.split("@")[languageIndex]; 
    }

    //explode our string and wrap each item in a p tag
    finalString = finalString.split(";").map(function (item) {
        return "<p class='append-answer-string'>" + item + "</p>";
    }).join("");

    //insert our popover toggles into our string
    $(".question-container").each(function (index) {
        var qCode = this.id || null;
        if (finalString.indexOf(qCode) !== -1) {
            targets.push(qCode);
            var _this = $(this).addClass("hidden");
            finalString = finalString.replace(qCode, getPopoverToggle(qCode, {
                type: getQuestionType(_this),
                default: qCode
            }));
        }
    });


    //append our string to our primary question
    options.question.find(".sentence-append-location").append(finalString);

    $.each(targets, function (index, qCode) {
        var _question = $("#" + qCode);
        setSelectedString(_question, getSelectedString(_question));
    });

    //bind listener for setting answers and popover content
    options.question
        .on("click", ".popover-item", toggleAnswer)
        .on("click", ".popover-close", hidePopovers)
        .on("click", ".text-save", function (e) {
            e.preventDefault();
            hidePopovers(e, true);
        })
        .on("keyup", ".popup-text", toggleText)
        .find("[data-toggle=popover]")
        .popover({
            html: true,
            content: getPopoverContent,
            placement: "bottom",
            trigger: "click"
        }).on('shown.bs.popover', function (e, ui) {
        handleCheckboxSaveBtn();
        setTimeout(function () {
            var _this = $(".popover:visible");
            if (_this.find(".popover-text").length > 0) {
                _this.find("input[type=text]").first().focus();
            }
            _this.find(".popover-title").append('<span class="glyphicon glyphicon-remove-sign popover-close"></span>');
        }, 500);
    }).on('hidden.bs.popover', function (e, ui) {
        setTimeout(function () {
            showNextUnansweredPopover();
        }, 500);
    });


    options.storage = {};

    // showing first list on load
    if (options.storage.answered === 0) {
        showNextUnansweredPopover();
    }
    //showing next list on next
    onMoveNext(function (e) {
        var _popoverToggles = $(".popover-question:visible");
        options.storage.needed = _popoverToggles.length;
        options.storage.answered = _popoverToggles.filter(".answered").length;

        if (options.storage.answered !== options.storage.needed) {
            e.preventDefault();
            resetSubmitButtons();
            showErrorText(options.question);
            setTimeout(function () {
                showNextUnansweredPopover();
            }, 200);
        }
    });

    //make sure we don't have any left over stored answers we no longer want
    $("input[type=radio]").on("change", cleanRadioStorage);

    //allow the respondent to close the popover by clicking outside on the document
    $(document).on("click", hidePopovers).on("keypress", "form", function (e) {
        if (e.keyCode === 13) {
            e.preventDefault();
            $("[data-toggle=popover]").each(function () {
                var _this = $(this);
                ((_this.popover('hide').data('bs.popover') || {}).inState || {}).click = false;
            });
            showNextUnansweredPopover();
            return false;
        }
    });

    function showNextUnansweredPopover() {
        var _popovers = $(".popover-question");
        var _popover = _popovers.not(".answered").first();
        if ($(".popover").filter(":visible").length === 0 && _popover.length > 0) {
            _popover.popover('show');
        }
    }

    function getQuestionType(_question) {
        if (_question.is(".list-radio")) {
            return "radio";
        } else if (_question.is(".multiple-opt")) {
            return "checkbox";
        } else if (_question.is(".text-short")) {
            return "text";
        }

        return "unknown"
    }

    function hidePopovers(e, force) {
        var _target = $(e.target);

        if (!isDefined(force)) {
            force = false;
        }
        //close popovers other than one we may have just clicked
        if (!force) {
            $("[data-toggle=popover]").each(function () {
                var _this = $(this);
                if (_target.is(".popover-close") || (!_this.is(e.target) && _this.has(e.target).length === 0 && $('.popover').has(e.target).length === 0)) {
                    ((_this.popover('hide').data('bs.popover') || {}).inState || {}).click = false;
                }
            });
        } else {
            //closes all popovers regardless of where we clicked
            $("[data-toggle=popover]").popover("hide");
        }
    }

    function cleanRadioStorage(e) {
        e.stopPropagation();
        var _radio = $(this),
            _row = _radio.closest(".answer-item");
        _row.siblings(".answer-item").find("input[type=text]").val("");

        if (_row.closest(".list-radio").find("input[type=radio]:checked").length === 0) {
            _row.siblings("input[type=hidden]").val("");
        }
    }

    var textTimeout = 0;

    function toggleText(e) {
        // e.stopPropagation();
        clearTimeout(textTimeout);
        var _textInput = $(this),
            _answer = _textInput.closest(".popover-item");

        textTimeout = setTimeout(function () {
            toggleAnswerOther(_textInput, _answer);
        }, 400);
    }

    function toggleAnswerOther(_textInput, _answer) {
        var _question = $("#" + _answer.attr("data-stringTarget"));

        if (_textInput.val() !== "") {
            if (_answer.is(".popover-radio")) {
                toggleRadio(_answer);
            } else if (_answer.is(".popover-checkbox") && !_answer.is(".selected")) {
                toggleCheckbox(_answer);
            }
        } else {
            _answer.removeClass("selected");
        }

        storeText(_textInput);
        storeAnswer(_answer);

        setSelectedString(_question, getSelectedString(_question));
    }

    function toggleAnswer(e) {
        e.stopPropagation();
        var _answer = $(this),
            _question = $("#" + _answer.attr("data-stringTarget"));

        if (_answer.is(".disabled")) {
            return false;
        }

        if (_answer.is(".popover-other")) {
            return _answer.find("input[type=text]").focus();
        }

        if (_answer.is(".popover-radio")) {
            toggleRadio(_answer);
            hidePopovers(e, true);
        } else if (_answer.is(".popover-checkbox")) {
            toggleCheckbox(_answer);
        }

        storeAnswer(_answer);

        setSelectedString(_question, getSelectedString(_question));
    }

    function setSelectedString(_question, string) {
        var _stringStore = $("[data-question=" + _question.attr("id") + "]");

        if (string === "") {
            string = _stringStore.attr("data-default");
            _stringStore.removeClass("answered").addClass("default");
        } else {
            _stringStore.removeClass("default").addClass("answered");
        }
        _stringStore.text(string);
    }

    function getSelectedString(_question) {
        var _selectedRows = getSelectedRows(_question);
        var textArr = [];

        _selectedRows.each(function () {
            var _row = $(this);

            if (_row.attr("id").indexOf("other") !== -1 || _row.is(".text-item")) {
                textArr.push(_row.find("input[type=text]").val().trim());
            }
            else {
                //if label does not have class from lime label, we lower case it, else leave casing as is
                var _label = _row.find(".control-label"),
                    string = _label.find(".ignore-lowercase").length === 0 ?
                    lowerCaseFirstLetter(_label.text().trim()) :
                    _label.text().trim();

                textArr.push(string);
            }
        });

        var textString = textArr.join(", ");

        if (textArr.length > 1) {
            var pos = textString.lastIndexOf(',');
            textString = textString.substring(0, pos) + " &" + textString.substring(pos + 1)
        }

        return textString;
    }

    function lowerCaseFirstLetter(string) {
        var stringArr = string.split(" "),
            firstWord = stringArr[0];

        //if the first word is not I, lowercase it
        if (firstWord !== "I") {
            firstWord = firstWord.toLowerCase();
        }

        // remove first word from array and then rebuild with lowercased first word
        stringArr.shift();
        var restOfString = stringArr.join(" ");

        string = firstWord + " " + restOfString;
        return string;
    }

    function getSelectedRows(_question) {
        if (_question.is(".multiple-short-txt")) {
            return _question.find(".text-item").filter(function () {
                return $(this).find("input[type=text]").val().trim() !== "";
            });
        }
        return _question.find("input:checked:enabled").closest(".answer-item");
    }

    function toggleRadio(_answer) {
        _answer.addClass("selected");
        handleRadioSiblings(_answer);
    }

    function toggleCheckbox(_answer) {
        var _inputStore = $("#" + _answer.attr("data-target"));
        _answer.toggleClass("selected");

        if (_inputStore.is(".cbox-exclusive")) {
            if (_answer.is(".selected")) {
                _answer.siblings(".popover-item").addClass("disabled");
            } else {
                _answer.siblings(".popover-item").removeClass("disabled");
            }
        }
        handleCheckboxSaveBtn();
    }

    function handleCheckboxSaveBtn() {
        if ($('.popover-checkbox.selected').length > 0) {
            $('.text-save').addClass("answered-multi");
        } else {
            $('.text-save').removeClass("answered-multi");
        }
    }

    function storeAnswer(_answer) {
        var _inputStore = $("#" + _answer.attr("data-target")),
            checked = _answer.is(".selected");

        _inputStore.prop("checked", checked).attr("checked", checked);
        checkconditions(_inputStore.val(), _inputStore.attr("name"), _inputStore.attr("type"));
        _inputStore.trigger("change");
    }

    function storeText(_answer) {
        var _inputStore = $("#" + _answer.attr("data-target"));
        _inputStore.val(_answer.val());

        if (_inputStore.closest(".question-container").is(".multiple-short-txt")) {
            checkconditions(_inputStore.val(), _inputStore.attr("name"), _inputStore.attr("type"));
        }
    }

    function handleRadioSiblings(_answer) {
        _answer
            .closest(".list-group")
            .find(".popover-radio")
            .not(_answer)
            .removeClass("selected")
            .find("input[type=text]")
            .val("");
    }

    function getPopoverContent() {
        var _thisPopover = $(this),
            _targetQuestion = $("#" + _thisPopover.attr("data-question")),
            type = _thisPopover.attr("data-type");

        var content = "";
        switch (_thisPopover.attr("data-type")) {
            case "radio":
            case "checkbox":
                content = getAnswerOptions(_targetQuestion, type);
                break;
            case "text":
                content = getTextOptions(_targetQuestion, type);
                break;
            default:
                console.error("Type not defined in getPopoverContent(): ", _thisPopover, _targetQuestion);
                return false;
        }

        return content;
    }


    function getTextOptions(_targetQuestion, type) {
        var options = ["<div class='list-group'>"];
        _targetQuestion.find(".answer-item").not('.ls-hidden').each(function () {
            var _answerRow = $(this),
                label = "",
                _input = _answerRow.find("input[type=" + type + "]"),
                dataTarget = _input.attr("id"),
                extraClasses = "";

            //append text input if this is an other
            label += getOtherTextInput(_answerRow);

            var rowHTML = "<div class='list-group-item list-group-item popover-item popover-" +
                type + extraClasses + "' " +
                "data-stringTarget='" + _targetQuestion.attr("id") + "' " +
                "data-target='" + dataTarget + "'>" +
                label +
                "</div>";

            options.push(rowHTML);
        });
        options.push("</div>");
        return options.join(" ");
    }

    function getAnswerOptions(_targetQuestion, type) {
        var options = ["<div class='list-group'>"];
        _targetQuestion.find(".answer-item").not('.ls-hidden').each(function () {
            var _answerRow = $(this),
                label = _answerRow.find(".control-label, .answertext").html(),
                _input = _answerRow.find("input[type=" + type + "]"),
                dataTarget = _input.attr("id"),
                selected = _input.is(":checked") ? " selected" : "",
                extraClasses = _input.is(":disabled") ? " disabled" : "";

            //append text input if this is an other
            if (dataTarget.indexOf('SOTH') !== -1 || dataTarget.indexOf('other') !== -1) {
                label += getOtherTextInput(_answerRow);
                extraClasses += " popover-other";
            }

            var rowHTML = "<div class='list-group-item list-group-item popover-item popover-" +
                type + selected + extraClasses + "' " +
                "data-stringTarget='" + _targetQuestion.attr("id") + "' " +
                "data-target='" + dataTarget + "'>" +
                label +
                "</div>";

            options.push(rowHTML);
        });


        //adding the bottom checkmark row to confirm checked answers for mc
        if (_targetQuestion.hasClass('multiple-opt')) {
            options.push("<span class='input-group-addon text-save text-save-multi'><i class='fa fa-check-square'></i></span>");
        }

        options.push("</div>");


        return options.join(" ");
    }

    function getOtherTextInput(_answerRow) {
        var _storageInput = _answerRow.find("input[type=text]");
        var returnString = "<div class='input-group'><input type='text' class='form-control input-sm popup-text' " +
            "data-target='" + _answerRow.find("input[type=text]").attr("id") + "' " +
            "value='" + _storageInput.val() + "' ";
        returnString += isDefined(_storageInput.attr("maxlength")) ? "maxlength='" + _storageInput.attr("maxlength") + "' " : "";
        // returnString += "/><span class='input-group-addon text-save'><i class='fa fa-check-square'></i></span></div>";


        //TODO switch this?? to exlude from checkbox but keep for other text type qns? or is this just other specifies??
        if (_answerRow.hasClass('radio-text-item')) {
            returnString += "/><span class='input-group-addon text-save'><i class='fa fa-check-square'></i></span></div>";
        } else {
            returnString += "/></div>";
        }

        return returnString;
    }

    function getPopoverToggle(qCode, targetObj) {
        var returnString = "<span class='popover-wrapper'><span data-toggle='popover' " +
            "data-question='" + qCode + "' " +
            "data-type='" + targetObj.type + "' " +
            // "data-default='" + targetObj.default + "' " +
            "title='" + targetObj.default + "' ";

        returnString += isDefined(targetObj.maxlength) ? "data-maxlength='" + targetObj.maxlength + "' " : "";

        if (options.show_question_text) {
            var questionText = $("#" + qCode).find(".question-title-container").find(".question-text").find(".questiontext").text().trim();
            returnString += "class='popover-question popover-" + qCode + "' >" + questionText + "</span> <i class='fa fa-angle-down pull-right'></i></span>";
        }
        else {
            returnString += "class='popover-question popover-" + qCode + "' ></span> <i class='fa fa-angle-down pull-right'></i></span>";
        }

        return returnString;
    }
}
